@@ -1,6 +1,6 @@
-package Dist::Zilla::PluginBundle::RJBS;
+package Dist::Zilla::PluginBundle::RJBS 5.016;
 # ABSTRACT: BeLike::RJBS when you build your dists
-$Dist::Zilla::PluginBundle::RJBS::VERSION = '5.015';
+
 use Moose;
 use Dist::Zilla 2.100922; # TestRelease
 with
@@ -107,7 +107,17 @@ has weaver_config => (
 
 sub mvp_multivalue_args { qw(dont_compile) }
 
-sub mvp_aliases { return { 'perl-support' => 'perl_support' } }
+sub mvp_aliases {
+  return {
+    'is-task'       => 'is_task',
+    'major-version' => 'major_version',
+    'perl-support'  => 'perl_support',
+    'dont-compile'  => 'dont_compile',
+    'weaver-config' => 'weaver_config',
+    'manual-version'       => 'manual_version',
+    'package-name-version' => 'package_name_version',
+  }
+}
 
 has dont_compile => (
   is      => 'ro',
@@ -120,7 +130,7 @@ has package_name_version => (
   is      => 'ro',
   isa     => 'Bool',
   lazy    => 1,
-  default => sub { $_[0]->payload->{package_name_version} // 0 },
+  default => sub { $_[0]->payload->{package_name_version} // 1 },
 );
 
 has perl_support => (
@@ -131,7 +141,8 @@ has perl_support => (
 sub configure {
   my ($self) = @_;
 
-  $self->log_fatal("you must not specify both weaver_config and is_task")
+  # It'd be nice to have a Logger here... -- rjbs, 2021-04-24
+  die "you must not specify both weaver_config and is_task"
     if $self->is_task and $self->weaver_config ne '@RJBS';
 
   $self->add_plugins('Git::GatherDir');
@@ -257,7 +268,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 5.015
+version 5.016
 
 =head1 DESCRIPTION
 
