@@ -1,8 +1,8 @@
 use v5.20.0;
 use warnings;
-package Pod::Weaver::PluginBundle::RJBS;
+package Pod::Weaver::PluginBundle::RJBS 5.016;
 # ABSTRACT: RJBS's default Pod::Weaver config
-$Pod::Weaver::PluginBundle::RJBS::VERSION = '5.015';
+
 #pod =head1 OVERVIEW
 #pod
 #pod I<Roughly> equivalent to:
@@ -139,7 +139,7 @@ Pod::Weaver::PluginBundle::RJBS - RJBS's default Pod::Weaver config
 
 =head1 VERSION
 
-version 5.015
+version 5.016
 
 =head1 OVERVIEW
 
